summaryrefslogtreecommitdiff
path: root/tlsexternalcertprovider/build.gradle
diff options
context:
space:
mode:
Diffstat (limited to 'tlsexternalcertprovider/build.gradle')
-rw-r--r--tlsexternalcertprovider/build.gradle15
1 files changed, 5 insertions, 10 deletions
diff --git a/tlsexternalcertprovider/build.gradle b/tlsexternalcertprovider/build.gradle
index 608212f7..bb50eb03 100644
--- a/tlsexternalcertprovider/build.gradle
+++ b/tlsexternalcertprovider/build.gradle
@@ -7,14 +7,9 @@ plugins {
alias libs.plugins.android.application
}
-ext {
- bouncycastleVersion = '1.49'
-}
-
android {
compileSdkVersion 34
-
defaultConfig {
applicationId "de.blinkt.externalcertprovider"
minSdkVersion 21
@@ -51,11 +46,11 @@ android {
dependencies {
implementation fileTree(dir: 'libs', include: ['*.jar'])
implementation (
- //'org.bouncycastle:bcprov-jdk15on:' + bouncycastleVersion,
- //'org.bouncycastle:bcprov-ext-jdk15on:' + bouncycastleVersion,
- //'org.bouncycastle:bcpkix-jdk15on:' + bouncycastleVersion,
- 'org.bouncycastle:bcmail-jdk15on:' + bouncycastleVersion,
- //'org.bouncycastle:bcpg-jdk15on:' + bouncycastleVersion
+// libs.org.bouncycastle.bcprov.jdk15on,
+// libs.org.bouncycastle.bcprov.ext.jdk15on,
+// libs.org.bouncycastle.bcpkix.jdk15on,
+ libs.org.bouncycastle.bcmail.jdk15on,
+// libs.org.bouncycastle.bcpg.jdk15on,
)
testImplementation(libs.junit)